@@ -500,11 +500,17 @@ def _send_tiddler_revisions(environ, start_response, tiddler):
 
     title = 'Revisions of Tiddler %s' % tiddler.title
     title = environ['tiddlyweb.query'].get('title', [title])[0]
+    container = 'recipes' if tiddler.recipe else 'bags'
+
     if environ['tiddlyweb.filters']:
         tiddlers = Tiddlers(title=title)
     else:
         tiddlers = Tiddlers(title=title, store=store)
+
     tiddlers.is_revisions = True
+    tiddlers.link = '%s/revisions' % web.tiddler_url(environ, tiddler,
+            container=container, full=False)
+
     recipe = tiddler.recipe
     try:
         for revision in store.list_tiddler_revisions(tiddler):
