@@ -59,10 +59,13 @@ def _filter_readable(environ, entities, filters):
                 yield entity
 
     kept_entities = Container()
-    for entity in recursive_filter(filters, _load(entities)):
-        try:
-            entity.policy.allows(environ['tiddlyweb.usersign'], 'read')
-            kept_entities.add(entity)
-        except(UserRequiredError, ForbiddenError):
-            pass
+    try:
+        for entity in recursive_filter(filters, _load(entities)):
+            try:
+                entity.policy.allows(environ['tiddlyweb.usersign'], 'read')
+                kept_entities.add(entity)
+            except(UserRequiredError, ForbiddenError):
+                pass
+    except AttributeError, exc:
+        raise FilterError('malformed filter: %s' % exc)
     return kept_entities
